summaryrefslogtreecommitdiff
path: root/sys/dev
diff options
context:
space:
mode:
authorcgd <cgd@NetBSD.org>1999-07-03 05:55:23 +0000
committercgd <cgd@NetBSD.org>1999-07-03 05:55:23 +0000
commit636e8f46886e1e3c68eb34dbdd9f6cb0df71223b (patch)
treef01eca2890926a07898fc9bb0760d4b41d97d110 /sys/dev
parent2091d363f006a2862174437aa00a4349d698286c (diff)
'Dolphin' -> 'Dolphin Peripherals' where appropriate
Diffstat (limited to 'sys/dev')
-rw-r--r--sys/dev/pci/pucdata.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/sys/dev/pci/pucdata.c b/sys/dev/pci/pucdata.c
index 08b2b2b7846..79cbcd7193e 100644
--- a/sys/dev/pci/pucdata.c
+++ b/sys/dev/pci/pucdata.c
@@ -1,4 +1,4 @@
-/* $NetBSD: pucdata.c,v 1.5 1999/07/03 05:38:05 cgd Exp $ */
+/* $NetBSD: pucdata.c,v 1.6 1999/07/03 05:55:23 cgd Exp $ */
/*
* Copyright (c) 1998, 1999 Christopher G. Demetriou. All rights reserved.
@@ -46,16 +46,16 @@
const struct puc_device_description puc_devices[] = {
/*
* XXX no entry because I have no data:
- * XXX Dolphin 4006 (single parallel)
+ * XXX Dolphin Peripherals 4006 (single parallel)
*/
/*
* Dolphin 4014 (dual parallel port) card. PLX 9050, with
* a seemingly-lame EEPROM setup that puts the Dolphin IDs
* into the subsystem fields, and claims that it's a
* network/misc (0x02/0x80) device.
*/
- { "Dolphin 4014",
+ { "Dolphin Peripherals 4014",
{ 0x10b5, 0x9050, 0xd84d, 0x6810 },
{ 0xffff, 0xffff, 0xffff, 0xffff },
{
@@ -66,16 +66,16 @@ const struct puc_device_description puc_devices[] = {
/*
* XXX no entry because I have no data:
- * XXX Dolphin 4025 (single serial)
+ * XXX Dolphin Peripherals 4025 (single serial)
*/
/*
* Dolphin 4035 (dual serial port) card. PLX 9050, with
* a seemingly-lame EEPROM setup that puts the Dolphin IDs
* into the subsystem fields, and claims that it's a
* network/misc (0x02/0x80) device.
*/
- { "Dolphin 4035",
+ { "Dolphin Peripherals 4035",
{ 0x10b5, 0x9050, 0xd84d, 0x6808 },
{ 0xffff, 0xffff, 0xffff, 0xffff },
{
@@ -86,7 +86,7 @@ const struct puc_device_description puc_devices[] = {
/*
* XXX no entry because I have no data:
* XXX Dolphin 4078 (dual serial and single parallel)
*/
@@ -46,16 +46,16 @@
*/
/*
- * Dolphin 4014 (dual parallel port) card. PLX 9050, with
+ * Dolphin Peripherals 4014 (dual parallel port) card. PLX 9050, with
* a seemingly-lame EEPROM setup that puts the Dolphin IDs
* into the subsystem fields, and claims that it's a
@@ -66,16 +66,16 @@ const struct puc_device_description puc_devices[] = {
*/
/*
- * Dolphin 4035 (dual serial port) card. PLX 9050, with
+ * Dolphin Peripherals 4035 (dual serial port) card. PLX 9050, with
* a seemingly-lame EEPROM setup that puts the Dolphin IDs
* into the subsystem fields, and claims that it's a
@@ -86,7 +86,7 @@ const struct puc_device_description puc_devices[] = {
/*
* XXX no entry because I have no data:
- * XXX Dolphin 4078 (dual serial and single parallel)
+ * XXX Dolphin Peripherals 4078 (dual serial and single parallel)
*/